==> web2ldap-1.0.22.tar.gz: web2ldap-1.0.22/pylib/w2lapp/schema/plugins/edirectory.py <==
"""
web2ldap plugin classes for Novell eDirectory
(see draft-sermersheim-nds-ldap-schema)

$Id: edirectory.py,v 1.3 2009/06/26 18:51:41 michael Exp $
"""

from mspki.util import HexString

from pyweblib.forms import escapeHTML

from w2lapp.schema.syntaxes import DirectoryString,Integer,OctetString, \
  PostalAddress,PrintableString,CertificateRevocationList, \
  syntax_registry

from w2lapp.gui import DisplayDN

class CaseIgnoreList(PostalAddress):
  oid = '2.16.840.1.113719.1.1.5.1.6'
  desc = 'Case Ignore List'
  

class TaggedData(OctetString):
  oid = '2.16.840.1.113719.1.1.5.1.12'
  desc = 'Tagged Data'


class OctetList(OctetString):
  oid = '2.16.840.1.113719.1.1.5.1.13'
  desc = 'Octet List'


class TaggedString(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.14'
  desc = 'Tagged String'


class TaggedNameAndString(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.15'
  desc = 'Tagged Name And String'

  def displayValue(self,valueindex=0,commandbutton=0):
    try:
      ind2 = self.attrValue.rindex('#')
      ind1 = self.attrValue.rindex('#',0,ind2-1)
    except ValueError:
      return DirectoryString.displayValue(self,sid,form,ls,dn,valueindex,commandbutton)
    dn = self.attrValue[0:ind1]
    number = self.attrValue[ind1+1:ind2]
    dstring = self.attrValue[ind2+1:]
    return '<dl><dt>name:</dt><dd>%s</dd><dt>number:</dt><dd>%s</dd><dt>dstring:</dt><dd>%s</dd></dl>' % (
      DisplayDN(sid,form,ls,dn,commandbutton=commandbutton),
      number,
      '<code><font size="-1">%s</font></code>' % HexString(
        dstring,delimiter=':',wrap=64,linesep='<br>'
      ),
    )

class NDSReplicaPointer(OctetString):
  oid = '2.16.840.1.113719.1.1.5.1.16'
  desc = 'NDS Replica Pointer'


class NDSACL(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.17'
  desc = 'NDS ACL'


class NDSTimestamp(PrintableString):
  oid = '2.16.840.1.113719.1.1.5.1.19'
  desc = 'NDS Timestamp'


class Counter(Integer):
  oid = '2.16.840.1.113719.1.1.5.1.22'
  desc = 'Counter (NDS)'


class TaggedName(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.23'
  desc = 'Tagged Name'


class TypedName(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.25'
  desc = 'Typed Name'


try:
  from w2lapp.schema.syntaxes import XmlValue
except ImportError:
  pass
else:
  syntax_registry.registerAttrType(
    XmlValue.oid,[
      '2.16.840.1.113719.1.14.4.1.3', # XmlData
    ]
  )


# Register all syntax classes in this module
for symbol_name in dir():
  syntax_registry.registerSyntaxClass(eval(symbol_name))


# Workarounds for eDirectory

syntax_registry.registerAttrType(
  CertificateRevocationList.oid,[
    '2.16.840.1.113719.1.48.4.1.34', # certificateRevocationList in Novell eDirectory
  ]
)

==> web2ldap-1.0.26.tar.gz: web2ldap-1.0.26/pylib/w2lapp/schema/plugins/edirectory.py <==
"""
web2ldap plugin classes for Novell eDirectory
(see draft-sermersheim-nds-ldap-schema)

$Id: edirectory.py,v 1.7 2009/07/18 19:00:48 michael Exp $
"""

from mspki.util import HexString

from pyweblib.forms import escapeHTML

from w2lapp.schema.syntaxes import DirectoryString,Integer,OctetString, \
  PostalAddress,PrintableString,Certificate,CertificateRevocationList, \
  MultilineText,OID,syntax_registry

from w2lapp.gui import DisplayDN

class CaseIgnoreList(PostalAddress):
  oid = '2.16.840.1.113719.1.1.5.1.6'
  desc = 'Case Ignore List'
  

class TaggedData(OctetString):
  oid = '2.16.840.1.113719.1.1.5.1.12'
  desc = 'Tagged Data'


class OctetList(OctetString):
  oid = '2.16.840.1.113719.1.1.5.1.13'
  desc = 'Octet List'


class TaggedString(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.14'
  desc = 'Tagged String'


class IndexDefinition(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.6'
  desc = 'Index Definition'


class TaggedNameAndString(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.15'
  desc = 'Tagged Name And String'

  def displayValue(self,valueindex=0,commandbutton=0):
    try:
      ind2 = self.attrValue.rindex('#')
      ind1 = self.attrValue.rindex('#',0,ind2-1)
    except ValueError:
      return DirectoryString.displayValue(self,sid,form,ls,dn,valueindex,commandbutton)
    dn = self.attrValue[0:ind1]
    number = self.attrValue[ind1+1:ind2]
    dstring = self.attrValue[ind2+1:]
    return '<dl><dt>name:</dt><dd>%s</dd><dt>number:</dt><dd>%s</dd><dt>dstring:</dt><dd>%s</dd></dl>' % (
      DisplayDN(self._sid,self._form,self._ls,dn,commandbutton=commandbutton),
      number,
      '<code><font size="-1">%s</font></code>' % HexString(
        dstring,delimiter=':',wrap=64,linesep='<br>'
      ),
    )

class NDSReplicaPointer(OctetString):
  oid = '2.16.840.1.113719.1.1.5.1.16'
  desc = 'NDS Replica Pointer'


class NDSACL(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.17'
  desc = 'NDS ACL'


class NDSTimestamp(PrintableString):
  oid = '2.16.840.1.113719.1.1.5.1.19'
  desc = 'NDS Timestamp'


class Counter(Integer):
  oid = '2.16.840.1.113719.1.1.5.1.22'
  desc = 'Counter (NDS)'


class TaggedName(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.23'
  desc = 'Tagged Name'


class TypedName(DirectoryString):
  oid = '2.16.840.1.113719.1.1.5.1.25'
  desc = 'Typed Name'


try:
  from w2lapp.schema.syntaxes import XmlValue
except ImportError:
  pass
else:
  syntax_registry.registerAttrType(
    XmlValue.oid,[
      '2.16.840.1.113719.1.14.4.1.3', # XmlData
    ]
  )


class SnmpTrapDescription(MultilineText):
  oid = 'SnmpTrapDescription'
  desc = 'SNMP Trap Description'
  lineSep = '\x00'
  cols = 30

syntax_registry.registerAttrType(
  SnmpTrapDescription.oid,[
    '2.16.840.1.113719.1.6.4.4', # snmpTrapDescription
  ]
)


# Register all syntax classes in this module
for symbol_name in dir():
  syntax_registry.registerSyntaxClass(eval(symbol_name))


# Workarounds for eDirectory

syntax_registry.registerAttrType(
  Certificate.oid,[
    '2.16.840.1.113719.1.48.4.1.3', # nDSPKIPublicKeyCertificate
  ]
)

syntax_registry.registerAttrType(
  CertificateRevocationList.oid,[
    '2.16.840.1.113719.1.48.4.1.34', # certificateRevocationList in Novell eDirectory
  ]
)

syntax_registry.registerAttrType(
  OID.oid,
  [
    'supportedGroupingTypes',
  ]
)
